GitWorktree class
One git worktree entry, parsed from git worktree list --porcelain. Plain
value type (predictable-flutter). gc's git.Worktree
(internal/git/git.go:13-18).
Constructors
- GitWorktree({required String path, String head = '', String branch = ''})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited